[edk2-devel] [PATCH 46/79] NetworkPkg/Mtftp4Dxe: Fix various typos

Rabeda, Maciej maciej.rabeda at intel.com
Fri Dec 6 16:02:31 UTC 2019


Reviewed-by: Maciej Rabeda <maciej.rabeda at intel.com>

Thanks!
Maciej

-----Original Message-----
From: Philippe Mathieu-Daude <philmd at redhat.com> 
Sent: Tuesday, December 3, 2019 17:15
To: devel at edk2.groups.io
Cc: Antoine Coeur <coeur at gmx.fr>; Wu, Jiaxin <jiaxin.wu at intel.com>; Fu, Siyuan <siyuan.fu at intel.com>; Rabeda, Maciej <maciej.rabeda at intel.com>; Philippe Mathieu-Daude <philmd at redhat.com>
Subject: [PATCH 46/79] NetworkPkg/Mtftp4Dxe: Fix various typos

From: Antoine Coeur <coeur at gmx.fr>

Fix various typos in documentation, comments and debug strings.

Cc: Jiaxin Wu <jiaxin.wu at intel.com>
Cc: Siyuan Fu <siyuan.fu at intel.com>
Cc: Maciej Rabeda <maciej.rabeda at intel.com>
Reviewed-by: Philippe Mathieu-Daude <philmd at redhat.com>
Signed-off-by: Philippe Mathieu-Daude <philmd at redhat.com>
---
 NetworkPkg/Mtftp4Dxe/Mtftp4Driver.h  |  2 +-
 NetworkPkg/Mtftp4Dxe/Mtftp4Impl.h    |  2 +-
 NetworkPkg/Mtftp4Dxe/Mtftp4Option.h  |  2 +-  NetworkPkg/Mtftp4Dxe/Mtftp4Support.h |  2 +-  NetworkPkg/Mtftp4Dxe/Mtftp4Driver.c  |  4 ++--
 NetworkPkg/Mtftp4Dxe/Mtftp4Impl.c    | 10 +++++-----
 NetworkPkg/Mtftp4Dxe/Mtftp4Option.c  | 14 +++++++-------
 NetworkPkg/Mtftp4Dxe/Mtftp4Rrq.c     |  8 ++++----
 NetworkPkg/Mtftp4Dxe/Mtftp4Support.c |  6 +++---
 NetworkPkg/Mtftp4Dxe/Mtftp4Wrq.c     |  6 +++---
 10 files changed, 28 insertions(+), 28 deletions(-)

diff --git a/NetworkPkg/Mtftp4Dxe/Mtftp4Driver.h b/NetworkPkg/Mtftp4Dxe/Mtftp4Driver.h
index c90e69018629..6637c5a93ee5 100644
--- a/NetworkPkg/Mtftp4Dxe/Mtftp4Driver.h
+++ b/NetworkPkg/Mtftp4Dxe/Mtftp4Driver.h
@@ -113,7 +113,7 @@ Mtftp4ServiceBindingCreateChild (
   @param  This                   The service binding instance
   @param  ChildHandle            The child handle to destroy
 
-  @retval EFI_INVALID_PARAMETER  The parameter is invaid.
+  @retval EFI_INVALID_PARAMETER  The parameter is invalid.
   @retval EFI_UNSUPPORTED        The child may have already been destroyed.
   @retval EFI_SUCCESS            The child is destroyed and removed from the
                                  parent's child list.
diff --git a/NetworkPkg/Mtftp4Dxe/Mtftp4Impl.h b/NetworkPkg/Mtftp4Dxe/Mtftp4Impl.h
index 33393d42472c..b16ac0a4a483 100644
--- a/NetworkPkg/Mtftp4Dxe/Mtftp4Impl.h
+++ b/NetworkPkg/Mtftp4Dxe/Mtftp4Impl.h
@@ -201,7 +201,7 @@ Mtftp4WrqStart (
   Start the MTFTP session to download.
 
   It will first initialize some of the internal states then build and send a RRQ
-  reqeuest packet, at last, it will start receive for the downloading.
+  request packet, at last, it will start receive for the downloading.
 
   @param  Instance              The Mtftp session
   @param  Operation             The MTFTP opcode, it may be a EFI_MTFTP4_OPCODE_RRQ
diff --git a/NetworkPkg/Mtftp4Dxe/Mtftp4Option.h b/NetworkPkg/Mtftp4Dxe/Mtftp4Option.h
index 7bfe706f88c6..5f37b0f7b9e6 100644
--- a/NetworkPkg/Mtftp4Dxe/Mtftp4Option.h
+++ b/NetworkPkg/Mtftp4Dxe/Mtftp4Option.h
@@ -45,7 +45,7 @@ typedef struct {
   @param  OptionList             The point to get the option array.
 
   @retval EFI_INVALID_PARAMETER  The parametera are invalid or packet isn't a
-                                 well-formated OACK packet.
+                                 well-formatted OACK packet.
   @retval EFI_SUCCESS            The option array is build
   @retval EFI_OUT_OF_RESOURCES   Failed to allocate memory for the array
 
diff --git a/NetworkPkg/Mtftp4Dxe/Mtftp4Support.h b/NetworkPkg/Mtftp4Dxe/Mtftp4Support.h
index cfa7582faa4b..95e9bad43ef1 100644
--- a/NetworkPkg/Mtftp4Dxe/Mtftp4Support.h
+++ b/NetworkPkg/Mtftp4Dxe/Mtftp4Support.h
@@ -28,7 +28,7 @@ typedef struct {
 
   RRQ and WRQ have different requirements for Start and End.
   For example, during start up, WRQ initializes its whole valid block range
-  to [0, 0xffff]. This is bacause the server will send us a ACK0 to inform us
+  to [0, 0xffff]. This is because the server will send us a ACK0 to 
+ inform us
   to start the upload. When the client received ACK0, it will remove 0 from the
   range, get the next block number, which is 1, then upload the BLOCK1. For RRQ
   without option negotiation, the server will directly send us the BLOCK1 in diff --git a/NetworkPkg/Mtftp4Dxe/Mtftp4Driver.c b/NetworkPkg/Mtftp4Dxe/Mtftp4Driver.c
index 06c4e202d3ef..a795d262473e 100644
--- a/NetworkPkg/Mtftp4Dxe/Mtftp4Driver.c
+++ b/NetworkPkg/Mtftp4Dxe/Mtftp4Driver.c
@@ -30,7 +30,7 @@ EFI_SERVICE_BINDING_PROTOCOL  gMtftp4ServiceBindingTemplete = {
   @param SystemTable    The system table.
 
   @retval EFI_SUCCESS  The handles are successfully installed on the image.
-  @retval others       some EFI_ERROR occured.
+  @retval others       some EFI_ERROR occurred.
 
 **/
 EFI_STATUS
@@ -632,7 +632,7 @@ ON_ERROR:
   @param  This                   The service binding instance
   @param  ChildHandle            The child handle to destroy
 
-  @retval EFI_INVALID_PARAMETER  The parameter is invaid.
+  @retval EFI_INVALID_PARAMETER  The parameter is invalid.
   @retval EFI_UNSUPPORTED        The child may have already been destroyed.
   @retval EFI_SUCCESS            The child is destroyed and removed from the
                                  parent's child list.
diff --git a/NetworkPkg/Mtftp4Dxe/Mtftp4Impl.c b/NetworkPkg/Mtftp4Dxe/Mtftp4Impl.c
index 70bd693e4e3a..990a9ef03027 100644
--- a/NetworkPkg/Mtftp4Dxe/Mtftp4Impl.c
+++ b/NetworkPkg/Mtftp4Dxe/Mtftp4Impl.c
@@ -226,7 +226,7 @@ Mtftp4OverrideValid (
   @param  UdpCfgData             The UDP configure data to reconfigure the UDP_IO
 
   @retval TRUE                   The default address is retrieved and UDP is reconfigured.
-  @retval FALSE                  Some error occured.
+  @retval FALSE                  Some error occurred.
 
 **/
 BOOLEAN
@@ -342,7 +342,7 @@ Mtftp4ConfigUnicastPort (
   write file, and read directory.
 
   @param  This                   The MTFTP session
-  @param  Token                  The token than encapsues the user's request.
+  @param  Token                  The token than encapsules the user's request.
   @param  Operation              The operation to do
 
   @retval EFI_INVALID_PARAMETER  Some of the parameters are invalid.
@@ -601,9 +601,9 @@ EfiMtftp4GetModeData (
                                  2.MtftpConfigData.UseDefaultSetting is FALSE and
                                    MtftpConfigData.StationIp is not a valid IPv4
                                    unicast address.
-                                 3.MtftpCofigData.UseDefaultSetting is FALSE and
+                                 3.MtftpConfigData.UseDefaultSetting is 
+ FALSE and
                                    MtftpConfigData.SubnetMask is invalid.
-                                 4.MtftpCofigData.ServerIp is not a valid IPv4
+                                 4.MtftpConfigData.ServerIp is not a 
+ valid IPv4
                                    unicast address.
                                  5.MtftpConfigData.UseDefaultSetting is FALSE and
                                    MtftpConfigData.GatewayIp is not a valid IPv4 @@ -946,7 +946,7 @@ EfiMtftp4ReadDirectory (
   or ICMP ERROR packet. Retries occur only if no response packets are received
   from the MTFTPv4 server before the timeout expires.
   It is implemented with EfiMtftp4ReadFile: build a token, then pass it to
-  EfiMtftp4ReadFile. In its check packet callback abort the opertions.
+  EfiMtftp4ReadFile. In its check packet callback abort the operations.
 
   @param  This                   Pointer to the EFI_MTFTP4_PROTOCOL instance
   @param  OverrideData           Data that is used to override the existing
--- a/NetworkPkg/Mtftp4Dxe/Mtftp4Rrq.c
+++ b/NetworkPkg/Mtftp4Dxe/Mtftp4Rrq.c
@@ -34,7 +34,7 @@ Mtftp4RrqInput (
   Start the MTFTP session to download.
 
   It will first initialize some of the internal states then build and send a RRQ
-  reqeuest packet, at last, it will start receive for the downloading.
+  request packet, at last, it will start receive for the downloading.
 
   @param  Instance              The Mtftp session
   @param  Operation             The MTFTP opcode, it may be a EFI_MTFTP4_OPCODE_RRQ
@@ -55,7 +55,7 @@ Mtftp4RrqStart (
   //
   // The valid block number range are [1, 0xffff]. For example:
   // the client sends an RRQ request to the server, the server
-  // transfers the DATA1 block. If option negoitation is ongoing,
+  // transfers the DATA1 block. If option negotiation is ongoing,
   // the server will send back an OACK, then client will send ACK0.
   //
   Status = Mtftp4InitBlockRange (&Instance->Blocks, 1, 0xffff); @@ -544,8 +544,8 @@ Mtftp4RrqHandleOack (
 
     //
     // Save the multicast info. Always update the Master, only update the
-    // multicast IP address, block size, window size, timeoute at the first time. If IP
-    // address is updated, create a UDP child to receive the multicast.
+    // multicast IP address, block size, window size, timeout at the first time.
+    // If IP address is updated, create a UDP child to receive the multicast.
     //
     Instance->Master = Reply.Master;
 
diff --git a/NetworkPkg/Mtftp4Dxe/Mtftp4Support.c b/NetworkPkg/Mtftp4Dxe/Mtftp4Support.c
index ad2ff7bf3a3f..6ca4842107df 100644
--- a/NetworkPkg/Mtftp4Dxe/Mtftp4Support.c
+++ b/NetworkPkg/Mtftp4Dxe/Mtftp4Support.c
@@ -46,7 +46,7 @@ Mtftp4AllocateRange (
 
   RRQ and WRQ have different requirements for Start and End.
   For example, during start up, WRQ initializes its whole valid block range
-  to [0, 0xffff]. This is bacause the server will send us a ACK0 to inform us
+  to [0, 0xffff]. This is because the server will send us a ACK0 to 
+ inform us
   to start the upload. When the client received ACK0, it will remove 0 from the
   range, get the next block number, which is 1, then upload the BLOCK1. For RRQ
   without option negotiation, the server will directly send us the BLOCK1 in @@ -197,7 +197,7 @@ Mtftp4RemoveBlockNum (
     // 3. (Start < Num) && (End >= Num):
     //    if End == Num, only need to decrease the End by one because
     //    we have (Start < Num) && (Num == End), so (Start <= End - 1).
-    //    if (End > Num), the hold is splited into two holes, with
+    //    if (End > Num), the hold is split into two holes, with
     //    [Start, Num - 1] and [Num + 1, End].
     //
     if (Range->Start > Num) {
@@ -649,7 +649,7 @@ Mtftp4OnTimerTick (
     }
 
     //
-    // Retransmit the packet if haven't reach the maxmium retry count,
+    // Retransmit the packet if haven't reach the maximum retry count,
     // otherwise exit the transfer.
     //
     if (++Instance->CurRetry < Instance->MaxRetry) { diff --git a/NetworkPkg/Mtftp4Dxe/Mtftp4Wrq.c b/NetworkPkg/Mtftp4Dxe/Mtftp4Wrq.c
index bd13244b999b..5d479fad4e7c 100644
--- a/NetworkPkg/Mtftp4Dxe/Mtftp4Wrq.c
+++ b/NetworkPkg/Mtftp4Dxe/Mtftp4Wrq.c
@@ -171,7 +171,7 @@ Mtftp4WrqHandleAck (
   if (Expected < 0) {
 
     //
-    // The block range is empty. It may either because the the last
+    // The block range is empty. It may either because the last
     // block has been ACKed, or the sequence number just looped back,
     // that is, there is more than 0xffff blocks.
     //
@@ -245,11 +245,11 @@ Mtftp4WrqOackValid (
   @param  Instance              The MTFTP session
   @param  Packet                The received OACK packet
   @param  Len                   The length of the packet
-  @param  Completed             Whether the transmisson has completed. NOT used by
+  @param  Completed             Whether the transmission has completed. NOT used by
                                 this function.
 
   @retval EFI_SUCCESS           The OACK process is OK
-  @retval EFI_TFTP_ERROR        Some error occured, and the session reset.
+  @retval EFI_TFTP_ERROR        Some error occurred, and the session reset.
 
 **/
 EFI_STATUS
diff --git a/NetworkPkg/Mtftp4Dxe/Mtftp4Option.c b/NetworkPkg/Mtftp4Dxe/Mtftp4Option.c
index 013fe008eee8..21c1e421392b 100644
--- a/NetworkPkg/Mtftp4Dxe/Mtftp4Option.c
+++ b/NetworkPkg/Mtftp4Dxe/Mtftp4Option.c
@@ -18,13 +18,13 @@ CHAR8 *mMtftp4SupportedOptions[MTFTP4_SUPPORTED_OPTIONS] = {
 
 
 /**
-  Check whether two ascii strings are equel, ignore the case.
+  Check whether two ascii strings are equal, ignore the case.
 
   @param  Str1                   The first ascii string
   @param  Str2                   The second ascii string
 
   @retval TRUE                   Two strings are equal when case is ignored.
-  @retval FALSE                  Two string are not equal.
+  @retval FALSE                  Two strings are not equal.
 
 **/
 BOOLEAN
@@ -93,7 +93,7 @@ NetStringToU32 (
   Convert a string of the format "192.168.0.1" to an IP address.
 
   @param  Str                    The string representation of IP
-  @param  Ip                     The varible to get IP.
+  @param  Ip                     The variable to get IP.
 
   @retval EFI_INVALID_PARAMETER  The IP string is invalid.
   @retval EFI_SUCCESS            The IP is parsed into the Ip
@@ -126,7 +126,7 @@ NetStringToIp (
     Addr = (Addr << 8) | Byte;
 
     //
-    // Skip all the digitals and check whether the sepeator is the dot
+    // Skip all the digitals and check whether the separator is the dot
     //
     while (NET_IS_DIGIT (*Str)) {
       Str++;
@@ -230,7 +230,7 @@ Mtftp4FillOptions (
   @param  OptionList             The point to get the option array.
 
   @retval EFI_INVALID_PARAMETER  The parametera are invalid or packet isn't a
-                                 well-formated OACK packet.
+                                 well-formatted OACK packet.
   @retval EFI_SUCCESS            The option array is build
   @retval EFI_OUT_OF_RESOURCES   Failed to allocate memory for the array
 
@@ -314,7 +314,7 @@ Mtftp4ExtractMcast (
   UINT32                    Num;
 
   //
   // The multicast option is formated like "204.0.0.1,1857,1"
   // The server can also omit the ip and port, use ",,1"
   //
   if (*Value == ',') {
@@ -461,7 +461,7 @@ Mtftp4ParseOption (
     } else if (NetStringEqualNoCase (This->OptionStr, (UINT8 *) "multicast")) {
       //
       // Multicast option, if it is a request, the value must be a zero
       // length string, otherwise, it is formated like "204.0.0.1,1857,1\0"
       //
       if (Request) {
         if (*(This->ValueStr) != '\0') { diff --git a/NetworkPkg/Mtftp4Dxe/Mtftp4Rrq.c b/NetworkPkg/Mtftp4Dxe/Mtftp4Rrq.c
@@ -314,7 +314,7 @@ Mtftp4ExtractMcast (
 
   //
-  // The multicast option is formated like "204.0.0.1,1857,1"
+  // The multicast option is formatted like "204.0.0.1,1857,1"
   // The server can also omit the ip and port, use ",,1"
   //
@@ -461,7 +461,7 @@ Mtftp4ParseOption (
       //
       // Multicast option, if it is a request, the value must be a zero
-      // length string, otherwise, it is formated like "204.0.0.1,1857,1\0"
+      // length string, otherwise, it is formatted like "204.0.0.1,1857,1\0"
       //
       if (Request) {
index 8e1338221b12..f1d456a6122d 100644
--
2.21.0

--------------------------------------------------------------------

Intel Technology Poland sp. z o.o.
ul. Slowackiego 173 | 80-298 Gdansk | Sad Rejonowy Gdansk Polnoc | VII Wydzial Gospodarczy Krajowego Rejestru Sadowego - KRS 101882 | NIP 957-07-52-316 | Kapital zakladowy 200.000 PLN.

Ta wiadomosc wraz z zalacznikami jest przeznaczona dla okreslonego adresata i moze zawierac informacje poufne. W razie przypadkowego otrzymania tej wiadomosci, prosimy o powiadomienie nadawcy oraz trwale jej usuniecie; jakiekolwiek
przegladanie lub rozpowszechnianie jest zabronione.
This e-mail and any attachments may contain confidential material for the sole use of the intended recipient(s). If you are not the intended recipient, please contact the sender and delete all copies; any review or distribution by
others is strictly prohibited.

-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.

View/Reply Online (#51996): https://edk2.groups.io/g/devel/message/51996
Mute This Topic: https://groups.io/mt/67501339/1813853
Group Owner: devel+owner at edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub  [edk2-devel-archive at redhat.com]
-=-=-=-=-=-=-=-=-=-=-=-





More information about the edk2-devel-archive mailing list